Draws the data coloured by hard classification with the component quantile-regression lines, and a panel of the estimated component error densities (mirroring Wu & Yao Figs. 1, 3–5).
Arguments
- x
A
"mixqr"object.- which
"both"(default),"fit", or"density".- ...
Passed to
graphics::plot().